@@ -23,7 +23,7 @@ $service->email($email)
 ;
 
 # debug
-#$service->debug(1);
+$service->debug(1);
 
 # client email
 if ((defined $client_email) && ($client_email ne '')) {
